@@ -164,7 +164,7 @@ class FlaviusHeader(FlaviusBase):
 
         return super(FlaviusHeader, self).search(query=query)
     
-    def create(self, query=dist(slip_type=0)):
+    def create(self, query=dict(slip_type=0)):
         return super(FlaviusHeader, self).create(query=query)
 
 
